"use strict";
this.name        = "Police_Scanner_Upgrade"; 
this.author      = "capt murphy"; 
this.copyright   = "2011 capt murphy";
this.licence     = "CC BY-NC-SA 3.0"; // see http://creativecommons.org/licenses/by-nc-sa/3.0/ for more info.
this.description = "Upgrade to the IFF Scanner System. Shows ships with offender or fugitive status in different scanner colours"; 
this.version     = "1.3.1";

// event handler driven function to allow scanner to be resold.
this.playerBoughtEquipment = function(equipmentKey)
{
	if(equipmentKey === "EQ_POLICE_SCANNER_UPGRADE_REMOVAL")
		{
			player.ship.removeEquipment("EQ_POLICE_SCANNER_UPGRADE");
			player.ship.removeEquipment("EQ_POLICE_SCANNER_UPGRADE_REMOVAL");
			player.credits += (EquipmentInfo.infoForKey("EQ_POLICE_SCANNER_UPGRADE").price * 0.1 * 0.6);
		}
}
// event handler driven function which starts a timer when player is in yellow or red alert.
this.alertConditionChanged = function(newAlert, oldAlert)
{
	if (player.ship.equipmentStatus("EQ_POLICE_SCANNER_UPGRADE") !== "EQUIPMENT_OK" && player.ship.equipmentStatus("EQ_POLICE_SCANNER_UPGRADE") !== "EQUIPMENT_DAMAGED")
	{return;} // still run timer when equipment damaged in case fixed on the fly.
	switch (newAlert)
	{
		case 0 || 1:
		{
		if (this.psu_updatescannerTimer && this.psu_updatescannerTimer.isRunning)
		{
			this.psu_updatescannerTimer.stop();
		}
		}
		break;
		case 2 || 3:
		{
		if (!this.psu_updatescannerTimer)
		{
			this.psu_updatescannerTimer = new Timer(this, this.psu_updatescanner, 0, 0.25);
		}
		else
		{
			this.psu_updatescannerTimer.start();
		}
		}
	}
}
// caller by timer every 0.25 seconds when player is on yellow or red alert to identify ships within scanner range with a bounty and apply custom scanner colours depending on whether they are currently hostile to player or not.
this.psu_updatescanner = function()
{	var counter;
	var arrayLength;
	if (player.ship.equipmentStatus("EQ_POLICE_SCANNER_UPGRADE") !== "EQUIPMENT_OK")
	{return;} // scanner not updated when equipment damaged.
	if (worldScripts["targetAutolock"] && missionVariables.targetAutolock === "TRUE")
	{this.psu_targetAutolockupdatescanner();} // calls alternative function when Target Autolock is installed and active.
	else
	{
	var targets = system.filteredEntities(this, function (entity){return (entity.scanClass === "CLASS_NEUTRAL" && entity.bounty !== 0)}, player.ship, player.ship.scannerRange); 
	if (targets.length > 0)
	{
	arrayLength = targets.length; // caching the length here makes the loop run a smidgen faster.
	for (counter = 0; counter < arrayLength;counter++)
	{
		if (targets[counter].hasHostileTarget && targets[counter].target === player.ship && player.alertHostiles)
		{
			this.psu_hostilecustomscannercolours (targets[counter]);
		}
		else
		{
			this.psu_assigncustomscannercolours (targets[counter]);
		}
	}
	}
	}
}
// Alternative function to assign custom scanner colours when Target Autolock is installed and active. Does not apply custom colours to the players current target so as not to conflict with Target Autolock OXP.
this.psu_targetAutolockupdatescanner = function()
{
	var counter;
	var arrayLength;
	var targets = system.filteredEntities(this, function (entity){return (entity.scanClass === "CLASS_NEUTRAL" && entity.bounty !== 0)}, player.ship, player.ship.scannerRange);
	if (targets.length > 0)
	{
	arrayLength = targets.length; // caching the length here makes the loop run a smidgen faster.
	for (counter = 0; counter < arrayLength ;counter++)
	{
		if (targets[counter].hasHostileTarget && targets[counter].target === player.ship && player.ship.target !== targets[counter] && player.alertHostiles)
		{
			this.psu_hostilecustomscannercolours (targets[counter]);
		}
		else if (player.ship.target !== targets[counter])
		{
			this.psu_assigncustomscannercolours (targets[counter]);
		}
	}
	}
}
// Assigns custom colours to ships with a bounty.
this.psu_assigncustomscannercolours = function (target)
{
	if (target.bounty > 50)
		{
			target.scannerDisplayColor1 = "orangeColor";
			target.scannerDisplayColor2 = "magentaColor";
		}
		else
		{
			target.scannerDisplayColor1 = "yellowColor";
			target.scannerDisplayColor2 = "orangeColor";
		}
}
// Assigns red colour to ships with a bounty who are targeting and hostile to player.
this.psu_hostilecustomscannercolours = function (target)
{
	target.scannerDisplayColor1 = "redColor";
	target.scannerDisplayColor2 = null;
}
// Event handler driven function to stop timer if player dies.
this.shipDied = function()
{
	if (this.psu_updatescannerTimer && this.psu_updatescannerTimer.isRunning)
		{
			this.psu_updatescannerTimer.stop();
		}
}
// Event handler driven functions to clear custom scanner colours in event of equipment damaged.
this.equipmentDamaged = function(equipment)
{
    var counter;
	var arrayLength;
	if (equipment === "EQ_POLICE_SCANNER_UPGRADE")
	{
		player.consoleMessage("Police IFF Scanner Upgrade is Damaged!");
		if (worldScripts["targetAutolock"] && missionVariables.targetAutolock === "TRUE")
		{this.psu_targetAutolockRemoveCustomColours();} // calls alternative function when Target Autolock is installed and active.
		else
		{
		var targets = system.filteredEntities(this, function (entity){return (entity.scanClass === "CLASS_NEUTRAL" && entity.bounty !== 0)});
		if (targets.length > 0)
		{
		arrayLength = targets.length; // caching the length here makes the loop run a smidgen faster.
		for (counter = 0; counter < arrayLength;counter++)
		{
		targets[counter].scannerDisplayColor1 = null;
		targets[counter].scannerDisplayColor2 = null;
		}
		}
		}
	}
}

this.psu_targetAutolockRemoveCustomColours = function()
{
    var counter;
	var arrayLength;
	var targets = system.filteredEntities(this, function (entity){return (entity.scanClass === "CLASS_NEUTRAL" && entity.bounty != 0)});
	if (targets.length > 0)
	{
	arrayLength = targets.length; // caching the length here makes the loop run a smidgen faster.
	var playerTarget = player.ship.target; // caching the player target here makes the loop run a smidgen faster.
	for (counter = 0; counter < arrayLength;counter++)
	{
		if (playerTarget !== targets[counter])
		{
			targets[counter].scannerDisplayColor1 = null;
			targets[counter].scannerDisplayColor2 = null;
		}
	}
	}
}


 
	
